@@ -1,7 +1,7 @@
-__version__="4.3.0"
-__copyright__="Copyright (c) 2001 - 2021 The SCons Foundation"
+__version__="4.4.0"
+__copyright__="Copyright (c) 2001 - 2022 The SCons Foundation"
 __developer__="_reproducible"
-__date__="Fri, 19 Nov 2021 00:35:11 +0200"
+__date__="Sun, 07 Aug 2022 13:52:56 +0200"
 __buildsys__="_reproducible"
 __revision__=""
 __build__=""
